======================
Cross-project features
======================

Many features are common to all the OpenStack services and are consistent in
their configuration and deployment patterns. Unless explicitly noted, you can
safely assume that the features in this chapter are supported and configured
in a consistent manner.

.. toctree::
   :maxdepth: 2

   cross-project-cors.rst
